## dbt-snowflake 1.11.0 - December 22, 2025

### Features

- Support Iceberg REST with Catalog Linked Databases in Snowflake ([#1251](https://github.com/dbt-labs/dbt-adapters/issues/1251))
- Add cluster by config in Snowflake for dynamic tables ([#706](https://github.com/dbt-labs/dbt-adapters/issues/706))
- Add support for incremental materializations using iceberg rest catalog / catalog linked db  ([#1123](https://github.com/dbt-labs/dbt-adapters/issues/1123))
- Support for scalar functions ([#1292](https://github.com/dbt-labs/dbt-adapters/issues/1292))
- Remove catalog from target_relation in incremental macro ([#1376](https://github.com/dbt-labs/dbt-adapters/issues/1376))
- Add basic support for materializing tables in a Glue Catalog Linked Database with Iceberg REST ([#1377](https://github.com/dbt-labs/dbt-adapters/issues/1377))
- Add platform_detection_timeout_seconds configuration param to disable eager metadata detection in the snowflake-connector ([#1278](https://github.com/dbt-labs/dbt-adapters/issues/1278))
- Support volatility setting in sql UDFs ([#1345](https://github.com/dbt-labs/dbt-adapters/issues/1345))
- Add support for python UDFs ([#1410](https://github.com/dbt-labs/dbt-adapters/issues/1410))
- Allow partition_by model config for Snowflake Iceberg tables ([#1349](https://github.com/dbt-labs/dbt-adapters/issues/1349))
- Add support for python aggregate functions ([#1432](https://github.com/dbt-labs/dbt-adapters/issues/1432))
- Add support for UDF/UDAF default arguments ([#1442](https://github.com/dbt-labs/dbt-adapters/issues/1442))
- Log when underscores in Snowflake account names are replaced with hyphens. ([#1467](https://github.com/dbt-labs/dbt-adapters/issues/1467))
- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))

### Fixes

- Fix adapter.get_relation to find quoted case-sensitive relations ([#694](https://github.com/dbt-labs/dbt-adapters/issues/694))
- quote columns when altering tables for incremental materialization ([#695](https://github.com/dbt-labs/dbt-adapters/issues/695))
- fix table and column descriptions for snowflake iceberg tables ([#1015](https://github.com/dbt-labs/dbt-adapters/issues/1015))
- Rename DT temp tables to avoid problematic drops ([#713](https://github.com/dbt-labs/dbt-adapters/issues/713))
- Omit external volume from DDL when not provided in the YAML file ([#772](https://github.com/dbt-labs/dbt-adapters/issues/772))
- fix issue where incorrect varchar size is applied for iceberg table columns ([#1257](https://github.com/dbt-labs/dbt-adapters/issues/1257))
- handle non-model node types being passed to generate_database_name ([#1309](https://github.com/dbt-labs/dbt-adapters/issues/1309))
- Fix references to function properties in funciton macros ([#1365](https://github.com/dbt-labs/dbt-adapters/issues/1365))
- Set client prefetch threads to 1 to prevent deadlock at exit ([#1368](https://github.com/dbt-labs/dbt-adapters/issues/1368))
- Preserve collation when altering a column size ([#1258](https://github.com/dbt-labs/dbt-adapters/issues/1258))
- Ensure selection time filter timezone matches the delete filter for microbatch ([#955](https://github.com/dbt-labs/dbt-adapters/issues/955), [#892](https://github.com/dbt-labs/dbt-adapters/issues/892))
- Correct volatility specification for python functions ([#1504](https://github.com/dbt-labs/dbt-adapters/issues/1504))

### Under the Hood

- Improve snowflake connector log handling ([#1399](https://github.com/dbt-labs/dbt-adapters/issues/1399))
- Update bigquery job handling to invoke job.cancel on timeout ([#1355](https://github.com/dbt-labs/dbt-adapters/issues/1355))
- Test handling of unknown function macro lookup ([#1344](https://github.com/dbt-labs/dbt-adapters/issues/1344))
- Update default python runtime version ([#1492](https://github.com/dbt-labs/dbt-adapters/issues/1492))

### Dependencies

- bump dbt-adapters version pin floor to >=1.16.6  ([#1328](https://github.com/dbt-labs/dbt-adapters/pull/1328))
- Upgrade snowflake-connector-python to 4.0.0 ([#1368](https://github.com/dbt-labs/dbt-adapters/pull/1368))
- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
- Bump minimum dbt-adapters to 1.19.0█ ([#1421](https://github.com/dbt-labs/dbt-adapters/pull/1421))

### Contributors
- [@ajhlee-dbit](https://github.com/ajhlee-dbit) ([#1349](https://github.com/dbt-labs/dbt-adapters/issues/1349))
- [@dlouseiro](https://github.com/dlouseiro) ([#772](https://github.com/dbt-labs/dbt-adapters/issues/772))
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1492](https://github.com/dbt-labs/dbt-adapters/issues/1492))
- [@nazliander](https://github.com/nazliander) ([#706](https://github.com/dbt-labs/dbt-adapters/issues/706))
- [@nishan-soni](https://github.com/nishan-soni) ([#1467](https://github.com/dbt-labs/dbt-adapters/issues/1467))
- [@prashantpiyush](https://github.com/prashantpiyush) ([#694](https://github.com/dbt-labs/dbt-adapters/issues/694))
- [@sandeepmullangi2](https://github.com/sandeepmullangi2) ([#1015](https://github.com/dbt-labs/dbt-adapters/issues/1015))
- [@skadyan](https://github.com/skadyan) ([#695](https://github.com/dbt-labs/dbt-adapters/issues/695))
- [@wiggzz](https://github.com/wiggzz) ([#1368](https://github.com/dbt-labs/dbt-adapters/issues/1368), [#1368](https://github.com/dbt-labs/dbt-adapters/pull/1368))
